FlutxNavigation class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
config()
→ Map<String, dynamic>
-
Injects navigatorKey and navigatorObservers using the spread operator
-
configure({TransitionType? defaultTransition, Duration? defaultDuration})
→ void
-
Configure default transition and duration